==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/mk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информациите за процесорот не се достапни",
    "Load average" : "Просечно искористување",
    "Last minute" : "Последнава минута",
    "Memory info not available" : "Информации за меморијата не се достапни",
    "Total" : "Вкупно",
    "Current usage" : "Моментално искористување",
    "Users" : "Корисници",
    "Groups" : "Групи",
    "Links" : "Линкови",
    "Mails" : "Е-пошта пораки",
    "Federated sent" : "Испратени федерални споделувања",
    "Federated received" : "Примени федерални споделувања",
    "Talk conversations" : "Talk разговори",
    "24 hours" : "24 часа",
    "1 hour" : "1 час",
    "5 mins" : "5 минути",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "System" : "Систем",
    "Monitoring" : "Следење",
    "Monitoring app with useful server information" : "Апликација за мониторирање и корисни информации за серверот",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Овозможува корисни информации за серверот, како искористеност на процесорот, искористеност на меморијата, искористеност на просторот на дискот, број на корисници, итн.",
    "Operating System" : "Оперативен систем",
    "CPU" : "Процесор",
    "Memory" : "Меморија",
    "Server time" : "Времето на серверот",
    "Uptime" : "Време на работа",
    "Time Servers" : "Сервери за време",
    "Load" : "Искористеност",
    "Disk" : "Диск",
    "Mount" : "Монтиран",
    "Filesystem" : "Податоци",
    "Size" : "Големина",
    "Available" : "Достапно",
    "Used" : "Излезна порта",
    "You will get a notification once one of your disks is nearly full." : "Ќе добиете известување кога дискот ќе пред исполнување",
    "Files:" : "Датотеки:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободен простор:",
    "Network" : "Мрежа",
    "Hostname" : "Име на серверот",
    "DNS" : "ДНС",
    "Gateway" : "Gateway",
    "Status" : "Статус",
    "Speed" : "Брзина",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Активни корисници",
    "Total users:" : "Вкупно корисници:",
    "Shares" : "Споделувања",
    "PHP" : "PHP",
    "Version:" : "Верзија:",
    "Memory Limit:" : "Лимит на меморијата:",
    "Max Execution Time:" : "Максимално време на извршување:",
    "Upload max size:" : "Максимална големина на прикачување:",
    "Database" : "База",
    "Type:" : "Вид:",
    "Size:" : "Големина:",
    "External monitoring tool" : "Надворешен уред за следење",
    "You can connect an external monitoring tool by using this end point:" : "Можете да поврзете надорешен уред за следење со користење на:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Доколку сакате преглед во JSON формат додадете \"?format=json\" на крај на адресата.",
    "Last 24 hours" : "Последниве 24 часа",
    "Last 1 hour" : "Последниов час",
    "Last 5 mins" : "Последниве 5 минути",
    "CPU load" : "Искористување на процесорот",
    "Memory usage" : "Искористување на меторијата",
    "Storage" : "Склад",
    "Users:" : "Корисници:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Инсталирани апликации:",
    "Apps updates available:" : "Достапни ажурирања за апликации:",
    "Did you know?" : "Дали сте знаеле?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Доколку сакате преглед во JSON формат додадете \"?format=json\" на крај на адресата!"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/mk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информациите за процесорот не се достапни",
    "Load average" : "Просечно искористување",
    "Last minute" : "Последнава минута",
    "Memory info not available" : "Информации за меморијата не се достапни",
    "Total" : "Вкупно",
    "Current usage" : "Моментално искористување",
    "Users" : "Корисници",
    "Groups" : "Групи",
    "Links" : "Линкови",
    "Mails" : "Е-пошта пораки",
    "Federated sent" : "Испратени федерални споделувања",
    "Federated received" : "Примени федерални споделувања",
    "Talk conversations" : "Talk разговори",
    "24 hours" : "24 часа",
    "1 hour" : "1 час",
    "5 mins" : "5 минути",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "System" : "Систем",
    "Monitoring" : "Следење",
    "Monitoring app with useful server information" : "Апликација за мониторирање и корисни информации за серверот",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Овозможува корисни информации за серверот, како искористеност на процесорот, искористеност на меморијата, искористеност на просторот на дискот, број на корисници, итн.",
    "Operating System" : "Оперативен систем",
    "CPU" : "Процесор",
    "Memory" : "Меморија",
    "Server time" : "Времето на серверот",
    "Uptime" : "Време на работа",
    "Load" : "Искористеност",
    "Disk" : "Диск",
    "Mount" : "Монтиран",
    "Filesystem" : "Податочен систем",
    "Size" : "Големина",
    "Available" : "Достапно",
    "Used" : "Искористено",
    "You will get a notification once one of your disks is nearly full." : "Ќе добиете известување кога дискот ќе пред исполнување",
    "Files:" : "Датотеки:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободен простор:",
    "Network" : "Мрежа",
    "Hostname" : "Име на серверот",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Статус",
    "Speed" : "Брзина",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Активни корисници",
    "Total users:" : "Вкупно корисници:",
    "Shares" : "Споделувања",
    "PHP" : "PHP",
    "Version:" : "Верзија:",
    "Memory Limit:" : "Лимит на меморијата:",
    "Max Execution Time:" : "Максимално време на извршување:",
    "Upload max size:" : "Максимална големина на прикачување:",
    "Database" : "База",
    "Type:" : "Вид:",
    "Size:" : "Големина:",
    "External monitoring tool" : "Надворешен уред за следење",
    "You can connect an external monitoring tool by using this end point:" : "Можете да поврзете надорешен уред за следење со користење на:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Доколку сакате преглед во JSON формат додадете \"?format=json\" на крај на адресата.",
    "Time Servers" : "Сервери за време",
    "Did you know?" : "Дали сте знаеле?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Доколку сакате преглед во JSON формат додадете \"?format=json\" на крај на адресата!"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
